@@ -34,6 +34,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
 
     def __init__(self, file_name, list_files=None):
 
+        self.element_type = "file_movie"
         self.list_files = list_files
 
         devedeng.interface_manager.interface_manager.__init__(self)
@@ -201,7 +202,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
             self.aspect_ratio_final = None
             self.converted_filename = None
 
-    def set_title(self, new_title):
+    def set_name(self, new_title):
         self.title_name = new_title
         self.emit('title_changed', self.title_name)
 
@@ -428,20 +429,16 @@ class file_movie(devedeng.interface_manager.interface_manager):
                     self.original_height * midle_aspect_ratio / self.aspect_ratio_final)
 
     def set_type(self, obj=None, disc_type=None):
-
         if (disc_type is not None):
             self.disc_type = disc_type
 
-    def delete_file(self):
-
+    def delete_element(self):
         return
 
     def on_help_clicked(self, b):
-
         help_file = devedeng.help.help("file.html")
 
     def properties(self):
-
         if (self.wfile_properties is not None):
             self.wfile_properties.present()
             return
@@ -747,24 +744,20 @@ class file_movie(devedeng.interface_manager.interface_manager):
             disc_player.play_film(os.path.join(
                 self.config.tmp_folder, "movie_preview.mpg"))
 
-    def store_file(self):
-
+    def store_element(self):
         data = self.serialize()
         if "files_to_set" in data:
             del data["files_to_set"]
-
+        data["element_type"] = "file_movie"
         return data
 
-    def restore_file(self, data):
-
+    def restore_element(self, data):
         self.unserialize(data)
 
     def on_select_all_clicked(self, b):
-
         sel = self.wtreeview_multiproperties.get_selection()
         sel.select_all()
 
     def on_unselect_all_clicked(self, b):
-
         sel = self.wtreeview_multiproperties.get_selection()
         sel.unselect_all()
